# Modules
import requests
import pyautogui
import time
import pandas
import subprocess
import os
from tkinter import messagebox, filedialog, IntVar
import json
import jsonschema
import firebase_admin
from firebase_admin import db, auth, credentials, firestore, app_check, App, datetime