from setuptools import *
setup(
    author="Runkang",
    author_email="informatic3650@gmail.com",
    name="pysmart365",
    packages=['pysmart365'],
    version='0.0.6',
    long_description='''This module is to simplify the functions of MicroSoftware and SmartSoft.''',
    description='This module is to simplify the functions of MicroSoftware and SmartSoft.',
    install_requires=[
        'screeninfo',
        'pandas',
        'pyautogui',
        'pytube',
        'pytube3',
        'firebase_admin'
        ],
    url="https://github.com/informatic365/PySmart365/"
)